PcapNGBlock

Trait PcapNGBlock 

pub trait PcapNGBlock {
    // Required methods
    fn big_endian(&self) -> bool;
    fn raw_data(&self) -> &[u8] ;
    fn data_len(&self) -> usize;
    fn data(&self) -> &[u8] ;
    fn header_len(&self) -> usize;

    // Provided methods
    fn block_type(&self) -> u32 { ... }
    fn block_length(&self) -> u32 { ... }
    fn block_length2(&self) -> u32 { ... }
    fn raw_header(&self) -> &[u8]  { ... }
    fn offset_options(&self) -> usize { ... }
    fn raw_options(&self) -> &[u8]  { ... }
}
Common methods for PcapNG blocks

Required Methods

fn big_endian(&self) -> bool

Returns true if block is encoded as big-endian

fn raw_data(&self) -> &[u8]

Raw block data (including header)

fn data_len(&self) -> usize

The length of inner data, if any

fn data(&self) -> &[u8]

The inner data, if any

fn header_len(&self) -> usize

The Header length (without options)

Provided Methods

fn block_type(&self) -> u32

The type of this block

fn block_length(&self) -> u32

The block length from the block header

fn block_length2(&self) -> u32

The block length from the block footer

fn raw_header(&self) -> &[u8]

Raw packet header (without options)

fn offset_options(&self) -> usize

Return the declared offset of options. Warning: the offset can be out of bounds, caller must test value before accessing data

fn raw_options(&self) -> &[u8]

Network packet options. Can be empty if packet does not contain options

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors