[][src]Trait pcap_parser::traits::PcapReaderIterator

pub trait PcapReaderIterator<R> where
    R: Read
{ fn next(&mut self) -> Result<(usize, PcapBlockOwned), ErrorKind<u32>>;
fn consume(&mut self, offset: usize); }

Iterator over pcap files

Iterator over pcap files. Each call to next will return the next block, and must be followed by call to consume to avoid reading the same data.

Required methods

fn next(&mut self) -> Result<(usize, PcapBlockOwned), ErrorKind<u32>>

fn consume(&mut self, offset: usize)

Loading content...

Implementors

impl<R> PcapReaderIterator<R> for LegacyPcapReader<R> where
    R: Read
[src]

impl<R> PcapReaderIterator<R> for PcapNGReader<R> where
    R: Read
[src]

Loading content...