[−][src]Enum pcap_parser::data::NfAttrType
Variants
PacketHdrpacket header structure: hardware protocol (2 bytes), nf hook (1 byte), padding (1 byte)
Markpacket mark value from the skbuff for the packet
Timestamppacket time stamp structure: seconds (8 bytes), microseconds (8 bytes)
IfIndexInDev32-bit ifindex of the device on which the packet was received, which could be a bridge group
IfIndexOutDev32-bit ifindex of the device on which the packet was sent, which could be a bridge group
IfIndexPhysInDev32-bit ifindex of the physical device on which the packet was received, which is not a bridge group
IfIndexPhysOutDev32-bit ifindex of the physical device on which the packet was sent, which is not a bridge group
HwAddrhardware address structure: address length (2 bytes), padding (1 byte), address (8 bytes)
Payloadpacket payload following the link-layer header
Prefixnull-terminated text string
Uid32-bit ifindex of the device on which the packet was received, which could be a bridge group
Seq32-bit sequence number for packets provided by this nflog device
SeqGlobal32-bit sequence number for packets provided by all nflog devices
Gid32-bit group ID that owned the socket on which the packet was sent or received
HwType32-bit Linux ARPHRD_ value for the device associated with the skbuff for the packet
HwHeaderMAC-layer header for the skbuff for the packet
HwLenlength of the MAC-layer header
Ctconntrack header (nfnetlink_conntrack.h)
CtInfoenum ip_conntrack_info