[−][src]Struct pcap_parser::traits::LegacyPcapBlock
Container for network data in legacy Pcap files
Methods
impl<'a> LegacyPcapBlock<'a>[src]
pub fn new(data: &[u8], big_endian: bool) -> Option<LegacyPcapBlock>[src]
pub fn origlen(&self) -> u32[src]
The length of the packet as it appeared on the network when it was
captured.
If cap_len and len differ, the actually saved packet size was
limited by snaplen.
pub fn caplen(&self) -> u32[src]
The number of bytes of packet data actually captured and saved in the file.
pub fn ts_sec(&self) -> u32[src]
The date and time when this packet was captured (seconds since epoch).
pub fn ts_usec(&self) -> u32[src]
The date and time when this packet was captured (microseconds part).
pub fn ts(&self) -> (u32, u32, u64)[src]
The date and time when this packet was captured (full resolution). Returns the seconds, fractional part value and unit (in number per second)
pub fn raw_data(&self) -> &[u8][src]
Raw packet data (including header)
pub fn raw_header(&self) -> &[u8][src]
Raw packet header
pub fn data(&self) -> &[u8][src]
Network packet data.
Can be shorter than caplen if packet does not contain enough data