[−][src]Trait pcap_parser::traits::PcapNGBlock
Common methods for PcapNG blocks
Required methods
pub fn big_endian(&self) -> bool[src]
Returns true if block is encoded as big-endian
pub fn raw_data(&self) -> &[u8][src]
Raw block data (including header)
pub fn data_len(&self) -> usize[src]
The length of inner data, if any
pub fn data(&self) -> &[u8][src]
The inner data, if any
pub fn header_len(&self) -> usize[src]
The Header length (without options)
Provided methods
pub fn block_type(&self) -> u32[src]
The type of this block
pub fn block_length(&self) -> u32[src]
The block length from the block header
pub fn block_length2(&self) -> u32[src]
The block length from the block footer
pub fn raw_header(&self) -> &[u8][src]
Raw packet header (without options)
pub fn offset_options(&self) -> usize[src]
Return the declared offset of options. Warning: the offset can be out of bounds, caller must test value before accessing data
pub fn raw_options(&self) -> &[u8][src]
Network packet options. Can be empty if packet does not contain options