[−][src]Trait pcap_parser::traits::PcapReaderIterator
Iterator over pcap files
Iterator over pcap files. Each call to next will return the next block,
and must be followed by call to consume to avoid reading the same data.
Required methods
fn next(&mut self) -> Result<(usize, PcapBlockOwned), ErrorKind<u32>>
fn consume(&mut self, offset: usize)
Implementors
impl<R> PcapReaderIterator<R> for LegacyPcapReader<R> where
R: Read, [src]
R: Read,
fn next(&mut self) -> Result<(usize, PcapBlockOwned), ErrorKind<u32>>[src]
fn consume(&mut self, offset: usize)[src]
impl<R> PcapReaderIterator<R> for PcapNGReader<R> where
R: Read, [src]
R: Read,